/**
 * @copyright 2016 Mumba Pty Ltd. All rights reserved.
 * @license   Apache-2.0
 */
import { Errors } from './Errors';
/**
 * A validation error list class.
 */
export declare class ValidationErrors extends Errors {
    /**
     * Add an error for a required property.
     *
     * @param {string} property - The name of the property.
     */
    required(property: string): void;
    /**
     * Add an error for a property that requires a unique value.
     *
     * @param {string} property - The name of the property.
     */
    unique(property: string): void;
    /**
     * Add an error for a string that is too short.
     *
     * @param {string} property - The name of the property.
     * @param {number} expects  - The minimum length that is expected for the string.
     */
    minLength(property: string, expects: number): void;
    /**
     * Add an error for a string that is too long.
     *
     * @param {string} property - The name of the property.
     * @param {number} expects  - The maximum length that is expected for the string.
     */
    maxLength(property: string, expects: number): void;
}
